TaeraeFlutterPlatform class abstract

Platform interface for host-specific flutter_taerae implementations.

Inheritance
  • Object
  • PlatformInterface
  • TaeraeFlutterPlatform
Implementers

Constructors

TaeraeFlutterPlatform()
Creates a platform interface instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
Returns a host-provided platform version string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance TaeraeFlutterPlatform
The default instance of TaeraeFlutterPlatform to use.
getter/setter pair