TaeraeFlutterWeb class

Web implementation of TaeraeFlutterPlatform.

Inheritance

Constructors

TaeraeFlutterWeb()
Creates a web platform implementation.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
The browser user-agent string for this runtime.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void
Registers this class as the active platform implementation.