TaeraeEdge class
Immutable directed graph edge.
Constructors
-
TaeraeEdge({required String id, required String from, required String to, String? type, Map<
String, Object?> properties = const <String, Object?>{}}) -
Creates a TaeraeEdge between
fromandto. -
TaeraeEdge.fromJson(Map<
String, Object?> json) -
Creates a TaeraeEdge from JSON.
factory
Properties
- from → String
-
Source node identifier.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable edge identifier.
final
-
properties
→ Map<
String, Object?> -
Arbitrary edge properties.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → String
-
Target node identifier.
final
- type → String?
-
Optional edge type.
final
Methods
-
copyWith(
{String? from, String? to, String? type, Map< String, Object?> ? properties}) → TaeraeEdge - Returns a copy with selected fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Serializes the edge into a JSON-safe map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited